@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -26,8 +26,6 @@
 
 #include "format.h"
 #include "xalloc.h"
-#include "error.h"
-#include "error-progname.h"
 #include "gettext.h"
 
 #define _(str) gettext (str)
@@ -162,8 +160,9 @@ format_get_number_of_directives (void *descr)
 }
 
 static bool
-format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
-	      bool equality, bool noisy, const char *pretty_msgstr)
+format_check (void *msgid_descr, void *msgstr_descr, bool equality,
+	      formatstring_error_logger_t error_logger,
+	      const char *pretty_msgstr)
 {
   struct spec *spec1 = (struct spec *) msgid_descr;
   struct spec *spec2 = (struct spec *) msgstr_descr;
@@ -191,14 +190,9 @@ format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
 	    {
 	      if (equality)
 		{
-		  if (noisy)
-		    {
-		      error_with_progname = false;
-		      error_at_line (0, 0, pos->file_name, pos->line_number,
-				     _("a format specification for argument '%s' doesn't exist in '%s'"),
-				     spec1->named[i].name, pretty_msgstr);
-		      error_with_progname = true;
-		    }
+		  if (error_logger)
+		    error_logger (_("a format specification for argument '%s' doesn't exist in '%s'"),
+				  spec1->named[i].name, pretty_msgstr);
 		  err = true;
 		  break;
 		}
