@@ -1,5 +1,5 @@
 /* Perl format strings.
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2004 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2003.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -28,8 +28,6 @@
 #include "xalloc.h"
 #include "xerror.h"
 #include "format-invalid.h"
-#include "error.h"
-#include "error-progname.h"
 #include "gettext.h"
 
 #define _(str) gettext (str)
@@ -131,7 +129,7 @@ numbered_arg_compare (const void *p1, const void *p2)
 }
 
 static void *
-format_parse (const char *format, char **invalid_reason)
+format_parse (const char *format, bool translated, char **invalid_reason)
 {
   unsigned int directives;
   unsigned int numbered_arg_count;
@@ -393,7 +391,7 @@ format_parse (const char *format, char **invalid_reason)
 		size = FAT_SIZE_PTR;
 		format++;
 	      }
-	  }	
+	  }
 
 	switch (*format)
 	  {
@@ -539,8 +537,9 @@ format_get_number_of_directives (void *descr)
 }
 
 static bool
-format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
-	      bool equality, bool noisy, const char *pretty_msgstr)
+format_check (void *msgid_descr, void *msgstr_descr, bool equality,
+	      formatstring_error_logger_t error_logger,
+	      const char *pretty_msgstr)
 {
   struct spec *spec1 = (struct spec *) msgid_descr;
   struct spec *spec2 = (struct spec *) msgstr_descr;
@@ -564,14 +563,9 @@ format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
 
 	  if (cmp > 0)
 	    {
-	      if (noisy)
-		{
-		  error_with_progname = false;
-		  error_at_line (0, 0, pos->file_name, pos->line_number,
-				 _("a format specification for argument %u, as in '%s', doesn't exist in 'msgid'"),
-				 spec2->numbered[j].number, pretty_msgstr);
-		  error_with_progname = true;
-		}
+	      if (error_logger)
+		error_logger (_("a format specification for argument %u, as in '%s', doesn't exist in 'msgid'"),
+			      spec2->numbered[j].number, pretty_msgstr);
 	      err = true;
 	      break;
 	    }
@@ -579,14 +573,9 @@ format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
 	    {
 	      if (equality)
 		{
-		  if (noisy)
-		    {
-		      error_with_progname = false;
-		      error_at_line (0, 0, pos->file_name, pos->line_number,
-				     _("a format specification for argument %u doesn't exist in '%s'"),
-				     spec1->numbered[i].number, pretty_msgstr);
-		      error_with_progname = true;
-		    }
+		  if (error_logger)
+		    error_logger (_("a format specification for argument %u doesn't exist in '%s'"),
+				  spec1->numbered[i].number, pretty_msgstr);
 		  err = true;
 		  break;
 		}
@@ -604,15 +593,9 @@ format_check (const lex_pos_ty *pos, void *msgid_descr, void *msgstr_descr,
 	      {
 		if (spec1->numbered[i].type != spec2->numbered[j].type)
 		  {
-		    if (noisy)
-		      {
-			error_with_progname = false;
-			error_at_line (0, 0, pos->file_name, pos->line_number,
-				       _("format specifications in 'msgid' and '%s' for argument %u are not the same"),
-				       pretty_msgstr,
-				       spec2->numbered[j].number);
-			error_with_progname = true;
-		      }
+		    if (error_logger)
+		      error_logger (_("format specifications in 'msgid' and '%s' for argument %u are not the same"),
+				    pretty_msgstr, spec2->numbered[j].number);
 		    err = true;
 		    break;
 		  }
@@ -742,7 +725,7 @@ main ()
 	line[--line_len] = '\0';
 
       invalid_reason = NULL;
-      descr = format_parse (line, &invalid_reason);
+      descr = format_parse (line, false, &invalid_reason);
 
       format_print (descr);
       printf ("\n");
