@@ -262,7 +262,7 @@ static const short yycheck[] =
       10,     0,    11,    15
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/local/share/bison/bison.simple"
+#line 3 "/home/haible/gnu/arch/linuxlibc6/share/bison/bison.simple"
 
 /* Skeleton output parser for bison,
 
@@ -575,7 +575,7 @@ yystpcpy (yydest, yysrc)
 # endif
 #endif
 
-#line 315 "/usr/local/share/bison/bison.simple"
+#line 315 "/home/haible/gnu/arch/linuxlibc6/share/bison/bison.simple"
 
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
@@ -1120,7 +1120,7 @@ case 18:
     break;
 }
 
-#line 705 "/usr/local/share/bison/bison.simple"
+#line 705 "/home/haible/gnu/arch/linuxlibc6/share/bison/bison.simple"
 
 
   yyvsp -= yylen;
