@@ -1,5 +1,5 @@
 /* Reading binary .mo files.
-   Copyright (C) 1995-1998, 2000-2003 Free Software Foundation, Inc.
+   Copyright (C) 1995-1998, 2000-2004 Free Software Foundation, Inc.
    Written by Ulrich Drepper <drepper@gnu.ai.mit.edu>, April 1995.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -147,6 +147,7 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
       nls_uint32 sysdep_segment_offset;
       nls_uint32 ss_length;
       nls_uint32 ss_offset;
+      size_t n;
 
       length += segsize;
 
@@ -170,7 +171,8 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
 		 _("file \"%s\" contains a not NUL terminated string, at %s"),
 		 bfp->filename, location);
 	}
-      length += 1 + strlen (bfp->data + ss_offset) + 1;
+      n = strlen (bfp->data + ss_offset);
+      length += (n > 1 ? 1 + n + 1 : n);
     }
 
   /* Allocate and fill the string.  */
@@ -205,10 +207,12 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
       if (!(ss_length > 0 && bfp->data[ss_offset + ss_length - 1] == '\0'))
 	abort ();
       n = strlen (bfp->data + ss_offset);
-      *p++ = '<';
+      if (n > 1)
+	*p++ = '<';
       memcpy (p, bfp->data + ss_offset, n);
       p += n;
-      *p++ = '>';
+      if (n > 1)
+	*p++ = '>';
     }
 
   if (p != string + length)
@@ -220,7 +224,7 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
 
 /* Reads an existing .mo file and adds the messages to mlp.  */
 void
-read_mo_file (message_list_ty *mlp, const char *fn)
+read_mo_file (message_list_ty *mlp, const char *filename)
 {
   FILE *fp;
   struct binary_mo_file bf;
@@ -228,21 +232,21 @@ read_mo_file (message_list_ty *mlp, const char *fn)
   unsigned int i;
   static lex_pos_ty pos = { __FILE__, __LINE__ };
 
-  if (strcmp (fn, "-") == 0 || strcmp (fn, "/dev/stdin") == 0)
+  if (strcmp (filename, "-") == 0 || strcmp (filename, "/dev/stdin") == 0)
     {
       fp = stdin;
       SET_BINARY (fileno (fp));
     }
   else
     {
-      fp = fopen (fn, "rb");
+      fp = fopen (filename, "rb");
       if (fp == NULL)
 	error (EXIT_FAILURE, errno,
-	       _("error while opening \"%s\" for reading"), fn);
+	       _("error while opening \"%s\" for reading"), filename);
     }
 
   /* Read the file contents into memory.  */
-  read_binary_mo_file (&bf, fp, fn);
+  read_binary_mo_file (&bf, fp, filename);
 
   /* Get a 32-bit number from the file header.  */
 # define GET_HEADER_FIELD(field) \
@@ -261,17 +265,18 @@ read_mo_file (message_list_ty *mlp, const char *fn)
 	{
 	unrecognised:
 	  error (EXIT_FAILURE, 0, _("file \"%s\" is not in GNU .mo format"),
-		 fn);
+		 filename);
 	}
     }
 
   header.revision = GET_HEADER_FIELD (revision);
 
-  /* We support only the major revision 0.  */
+  /* We support only the major revisions 0 and 1.  */
   switch (header.revision >> 16)
     {
     case 0:
-      /* Fill the header parts that apply to major revision 0.  */
+    case 1:
+      /* Fill the header parts that apply to major revisions 0 and 1.  */
       header.nstrings = GET_HEADER_FIELD (nstrings);
       header.orig_tab_offset = GET_HEADER_FIELD (orig_tab_offset);
       header.trans_tab_offset = GET_HEADER_FIELD (trans_tab_offset);
