@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -38,6 +38,9 @@
 
 #define _(s) gettext(s)
 
+#define SIZEOF(a) (sizeof(a) / sizeof(a[0]))
+
+
 /* The sh syntax is defined in POSIX:2001, see
      http://www.opengroup.org/onlinepubs/007904975/utilities/xcu_chap02.html
    Summary of sh syntax:
@@ -172,11 +175,9 @@ do_ungetc (int c)
 }
 
 
-/* Remove backslash followed by newline from the input stream.
-   Cope with potentially 2 characters of pushback.  */
+/* Remove backslash followed by newline from the input stream.  */
 
-/* Maximum used guaranteed to be < 4.  */
-static int phase1_pushback[4];
+static int phase1_pushback[1];
 static int phase1_pushback_length;
 
 static int
@@ -206,6 +207,7 @@ phase1_getc ()
     }
 }
 
+/* Supports only one pushback character.  */
 static void
 phase1_ungetc (int c)
 {
@@ -219,6 +221,8 @@ phase1_ungetc (int c)
       /* FALLTHROUGH */
 
     default:
+      if (phase1_pushback_length == SIZEOF (phase1_pushback))
+	abort ();
       phase1_pushback[phase1_pushback_length++] = c;
       break;
     }
@@ -498,13 +502,9 @@ is_operator_start (int c)
 #define OPENING_BACKQUOTE (2 * (UCHAR_MAX + 1) + '`')
 #define CLOSING_BACKQUOTE (3 * (UCHAR_MAX + 1) + '`')
 
-/* Maximum used guaranteed to be < 4.  */
-static int phase2_pushback[4];
+static int phase2_pushback[2];
 static int phase2_pushback_length;
 
-/* Forward declaration of local functions.  */
-static void phase2_ungetc (int c);
-
 /* Return the next character, with backslashes removed.
    The result is QUOTED(c) for some unsigned char c, if the next character
    is escaped sufficiently often to make it a regular constituent character,
@@ -663,6 +663,7 @@ phase2_getc ()
   return (open_singlequote || open_doublequote ? QUOTED (c) : c);
 }
 
+/* Supports 2 characters of pushback.  */
 static void
 phase2_ungetc (int c)
 {
@@ -676,6 +677,8 @@ phase2_ungetc (int c)
       /* FALLTHROUGH */
 
     default:
+      if (phase2_pushback_length == SIZEOF (phase2_pushback))
+	abort ();
       phase2_pushback[phase2_pushback_length++] = c;
       break;
     }
